@@ -137,7 +137,7 @@ class HttpRequest:
         Signal that the client application has specified a deprecated version
         of the RESTful API while the Python handler of the given HTTP request
         requires a compatible version (cf. parameter `compatibility_required`
-        of the decorator `@http_request `).
+        of the decorator `@http_request`).
         """
 
     class InvalidArgumentException(HttpRequestException):
@@ -1376,15 +1376,19 @@ def http_request(
         @functools.wraps(method)
         def decorated(self, request, *args, **kwargs):
             # Retrieve the identification of the RESTful API application that the
-            # HTTP request is sent to. Check the signature of the HTTP request when
+            # HTTP request is sent to.  Check the signature of the HTTP request when
             # required.
-            request.app_id = get_request_application_id(request, signature_required)
+            consumer_key = request.get_header('X-API-Key', data_type=HttpRequest.ArgumentDataType.hexadecimal)
+            if signature_required or consumer_key:
+                request.app_id = get_request_application_id(request, signature_required)
 
             # Retrieve the version of the RESTful API that the client application
             # has integrated, and detailed information about this client
             # application if identified.
             request.client_api_version, request.client_application = get_client_application_info(
-                request, compatibility_required)
+                request,
+                compatibility_required
+            )
 
             # Retrieve the login session of the user on behalf of whom the HTTP
             # request is sent to the RESTful API server.
@@ -1542,11 +1546,12 @@ def get_request_application_id(request, signature_required):
     #     checking the signature of a HTTP request has to be done before the
     #     authentication verification.
     consumer_key = request.get_header('X-API-Key', data_type=HttpRequest.ArgumentDataType.hexadecimal)
-    api_sig = request.get_header('X-API-Sig', is_required=signature_required)
+    client_signature = request.get_header('X-API-Sig', is_required=signature_required)
 
-    return ApplicationService().validate_signature(
-        consumer_key,
-        request.uri,
-        request.raw_body if request.headers.get('Content-Type').startswith('application/json') else None,
-        api_sig,
-        strict=signature_required)
+    if signature_required or client_signature:
+        return ApplicationService().validate_signature(
+            consumer_key,
+            request.uri,
+            request.raw_body if request.headers.get('Content-Type').startswith('application/json') else None,
+            client_signature,
+            strict=signature_required)
